%define module_name ppp

%define modules ppp_generic.ko ppp_mppe.ko
%define moduledir /updates/kernel/drivers/net

%{!?kernel:%define kernel %(rpm -q kernel-sourcecode --qf '%{RPMTAG_VERSION}-%{RPMTAG_RELEASE}' | tail -1)}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')
%define ktag %(echo "%{kernel}" | sed -e 's|-|_|g')

%define _with_smp %(test -d /usr/src/kernels/%{kernel}-smp-%{_target_cpu} && echo 1 || echo 0)
%define _with_hugemem %(test -d /usr/src/kernels/%{kernel}-hugemem-%{_target_cpu} && echo 1 || echo 0)

%define _libmoddir /lib/modules

Summary:  Linux UP driver enhanced for MSCHAP/MPPE encryption
Name: kernel-module-%{module_name}
Version: 1.0.2
Release: 2_%{ktag}
Group: System Environment/Kernel
Packager: e-smith developers <bugs@e-smith.com>
License: GPL
Source0: kernel_ppp_mppe-%{version}-src.tgz

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-%(id -u -n)-root

BuildRequires: kernel-sourcecode = %{kversion}-%{krelease}
BuildRequires: gcc

Requires: kernel = %{kversion}-%{krelease}
Requires: /boot/vmlinuz-%{kernel}

Provides: kernel-module-%{module_name} = %{version}-%{release}
Obsoletes: kernel-module-%{module_name}-%{kernel}

%description
Linux UP driver enhanced for MSCHAP/MPPE encryption

These drivers are built for kernel %{kernel}
and architecture %{_target_cpu}.
They might work with newer/older kernels.

%package -n kernel-smp-module-%{module_name}
Summary:  Linux SMP driver enhanced for MSCHAP/MPPE encryption
Group: System Environment/Kernel

Requires: kernel-smp = %{kversion}-%{krelease}
Requires: /boot/vmlinuz-%{kernel}smp

Provides: kernel-smp-module-%{module_name} = %{version}-%{release}
Obsoletes: kernel-smp-module-%{module_name}-%{kernel}

%description -n kernel-smp-module-%{module_name}
Linux SMP driver enhanced for MSCHAP/MPPE encryption

These drivers are built for kernel %{kernel}smp
and architecture %{_target_cpu}.
They might work with newer/older kernels.

%package -n kernel-hugemem-module-%{module_name}
Summary:  Linux Hugemem driver enhanced for MSCHAP/MPPE encryption
Group: System Environment/Kernel

Requires: kernel-hugemem = %{kversion}-%{krelease}
Requires: /boot/vmlinuz-%{kernel}hugemem

Provides: kernel-hugemem-module-%{module_name} = %{version}-%{release}
Obsoletes: kernel-hugemem-module-%{module_name}-%{kernel}

%description -n kernel-hugemem-module-%{module_name}
Linux Hugemem driver enhanced for MSCHAP/MPPE encryption

These drivers are built for kernel %{kernel}hugemem
and architecture %{_target_cpu}.
They might work with newer/older kernels.

%prep
%setup -n kernel_ppp_mppe-%{version}
./pre_build.sh %{_usrsrc}/linux-${kernel} . . %{kernel}
patch -p1 < patches/linux-2.6.2-pad.patch
patch -p1 < patches/02-ppp_generic.c.patch
patch -p1 < patches/03-ppp_mppe_compress.c.patch
patch -p1 < patches/04-ppp_mppe_compress.c_license.patch

%build
%{__rm} -rf %{buildroot}
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"

### Make UP module.
%{__make} KERNELRELEASE=%{kernel} -C /usr/src/kernels/%{kernel}-%{_target_cpu} M=`pwd` clean
%{__make} KERNELRELEASE=%{kernel} -C /usr/src/kernels/%{kernel}-%{_target_cpu} M=`pwd`
%{__install} -d -m0755 %{buildroot}%{_libmoddir}/%{kernel}%{moduledir}/
%{__install} -m0644 %{modules} %{buildroot}%{_libmoddir}/%{kernel}%{moduledir}

%if %{_with_smp}
### Make SMP module.
%{__make} KERNELRELEASE=%{kernel}smp -C /usr/src/kernels/%{kernel}-smp-%{_target_cpu} M=`pwd` clean
%{__make} KERNELRELEASE=%{kernel}smp -C /usr/src/kernels/%{kernel}-smp-%{_target_cpu} M=`pwd`
%{__install} -d -m0755 %{buildroot}%{_libmoddir}/%{kernel}smp%{moduledir}/
%{__install} -m0644 %{modules} %{buildroot}%{_libmoddir}/%{kernel}smp%{moduledir}
%endif

%if %{_with_hugemem}
### Make Hugemem module.
%{__make} KERNELRELEASE=%{kernel}hugemem -C /usr/src/kernels/%{kernel}-hugemem-%{_target_cpu} M=`pwd` clean
%{__make} KERNELRELEASE=%{kernel}hugemem -C /usr/src/kernels/%{kernel}-hugemem-%{_target_cpu} M=`pwd`
%{__install} -d -m0755 %{buildroot}%{_libmoddir}/%{kernel}hugemem%{moduledir}/
%{__install} -m0644 %{modules} %{buildroot}%{_libmoddir}/%{kernel}hugemem%{moduledir}
%endif

%install
### Install modules

%post -n kernel-module-%{module_name}
/sbin/depmod -ae %{kernel} || :

%postun -n kernel-module-%{module_name}
/sbin/depmod -ae %{kernel} || :

%post -n kernel-smp-module-%{module_name}
/sbin/depmod -ae %{kernel}smp || :

%postun -n kernel-smp-module-%{module_name}
/sbin/depmod -ae %{kernel}smp || :

%post -n kernel-hugemem-module-%{module_name}
/sbin/depmod -ae %{kernel}hugemem || :

%postun -n kernel-hugemem-module-%{module_name}
/sbin/depmod -ae %{kernel}hugemem || :

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%{_libmoddir}/%{kversion}-%{krelease}%{moduledir}/

%if %{_with_smp}
%files -n kernel-smp-module-%{module_name}
%defattr(-, root, root, 0755)
%{_libmoddir}/%{kversion}-%{krelease}smp%{moduledir}/
%endif

%if %{_with_hugemem}
%files -n kernel-hugemem-module-%{module_name}
%defattr(-, root, root, 0755)
%{_libmoddir}/%{kversion}-%{krelease}hugemem%{moduledir}/
%endif

%changelog
* Fri Apr 07 2006 Shad L. Lords <slords@mail.com>
- Initial package.
